Rdocumentation
powered by
Learn R Programming
robustreg (version 0.1-3)
derivPsiHuber: Derivative of Huber Psi Function
Description
Calculates residual from the first derivative of Huber psi function
Usage
derivPsiHuber(r,c)
Arguments
r
Value to be evaluated by function
c
Tuning constant
Value
r: Value to be evaluated by function
c: Tuning constant
Details
Calculates residual from the first derivative of Huber psi function
References
Huber
See Also
psiHuber()